==> nextcloud-27.1.4.tgz: nextcloud/apps/suspicious_login/l10n/de.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Neuer Anmeldeort erkannt",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Eine neue Anmeldung mit deinem Konto wurde erkannt. Die IP-Adresse %s wurde als verdächtig eingestuft. Falls du es selbst warst, ignoriere diese Meldung. Andernfalls solltest du dein Passwort ändern.",
    "Suspicious Login" : "Verdächtige Anmeldung",
    "More information ↗" : "Weitere Informationen ↗",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "Du kannst weitere Informationen erhalten, indem du die Schaltfläche drückst, um  %s zu öffnen und Informationen über die verdächtige IP-Adresse anzuzeigen.",
    "New login detected" : "Neue Anmeldung erkannt",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Erkenne und melde verdächtige Anmeldungen in Nextcloud\n",
    "Suspicious login detection" : "Erkennung verdächtiger Anmeldungen",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "Die Verdächtige-Anmeldung-Anwendung ist für diese Instanz aktiviert. Sie protokolliert die IP-Adressen, von denen sich Anwender. erfolgreich angemeldet haben und erstellt darauf basierend ein Kriterium, um vor Anmeldungen von verdächtigen IP-Adressen zu warnen.",
    "Training data statistics" : "Statistiken der Trainingsdaten",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Bisher hat die Anwendung {total} Anmeldungen (eingeschlossen Anwendungsverbindungen) erfasst, von denen {distinct} eindeutige (IP, UID) Tupel sind.",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Statistiken des Kriterienmodells",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Ein Kriterienmodell wurde bis jetzt noch nicht erstellt. Dies bedeutet, dass die Anwendung höchstwahrscheinlich erst kürzlich aktiviert wurde. Um ein Kriterienmodell erstellen zu können, wird eine verlässliche Datenbasis benötigt. Aus diesem Grund wartet die Anwendung, bis Anmeldungen von mindestens {days} Tagen erfasst wurden.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "Während der Begutachtung hat das letzte Kriterienmodell (Zeitraum {time}) {recall}% aller verdächtigen Anmeldungen (Widerruf) erfasst, wohingegen {precision}% der Anmeldungen, die als verdächtig eingestuft wurden, tatsächlich verdächtige Anmeldungen waren (Genauigkeit). Unten siehst du eine Visualisierung der historischen Modellleistung.",
    "Precision" : "Präzision",
    "Recall" : "Widerruf"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.9.tgz: nextcloud/apps/suspicious_login/l10n/de.js <==
OC.L10N.register(
    "suspicious_login",
    {
    "New login location detected" : "Neuer Anmeldeort erkannt",
    "More info about the suspicious IP address available on %s" : "Weitere Informationen zur verdächtigen IP-Adresse findest du unter %s",
    "A new login into your account was detected. The IP address %s was classified as suspicious. If this was you, you can ignore this message. Otherwise you should change your password." : "Eine neue Anmeldung mit deinem Konto wurde erkannt. Die IP-Adresse %s wurde als verdächtig eingestuft. Falls du es selbst warst, ignoriere diese Meldung. Andernfalls solltest du dein Passwort ändern.",
    "Open %s ↗" : "Öffne %s ↗",
    "Suspicious Login" : "Verdächtige Anmeldung",
    "New login detected" : "Neue Anmeldung erkannt",
    "Detect and warn about suspicious IPs logging into Nextcloud\n\t" : "Erkenne und melde verdächtige Anmeldungen in Nextcloud\n",
    "Suspicious login detection" : "Erkennung verdächtiger Anmeldungen",
    "The suspicious login app is enabled on this instance. It will keep track of IP addresses users successfully log in from and build a classifier that warns if a new login comes from a suspicious IP address." : "Die Verdächtige-Anmeldung-Anwendung ist für diese Instanz aktiviert. Sie protokolliert die IP-Adressen, von denen sich Anwender. erfolgreich angemeldet haben und erstellt darauf basierend ein Kriterium, um vor Anmeldungen von verdächtigen IP-Adressen zu warnen.",
    "Training data statistics" : "Statistiken der Trainingsdaten",
    "So far the app has captured {total} logins (including client connections), of which {distinct} are distinct (IP, UID) tuples." : "Bisher hat die Anwendung {total} Anmeldungen (eingeschlossen Anwendungsverbindungen) erfasst, von denen {distinct} eindeutige (IP, UID) Tupel sind.",
    "IPv4" : "IPv4",
    "IPv6" : "IPv6",
    "Classifier model statistics" : "Statistiken des Kriterienmodells",
    "No classifier model has been trained yet. This most likely means that you just enabled the app recently. Because the training of a model requires good data, the app waits until logins of at least {days} days have been captured." : "Ein Kriterienmodell wurde bis jetzt noch nicht erstellt. Dies bedeutet, dass die Anwendung höchstwahrscheinlich erst kürzlich aktiviert wurde. Um ein Kriterienmodell erstellen zu können, wird eine verlässliche Datenbasis benötigt. Aus diesem Grund wartet die Anwendung, bis Anmeldungen von mindestens {days} Tagen erfasst wurden.",
    "During evaluation, the latest model (trained {time}) has shown to capture {recall}% of all suspicious logins (recall), whereas {precision}% of the logins classified as suspicious are indeed suspicious (precision). Below you see a visualization of historic model performance." : "Während der Begutachtung hat das letzte Kriterienmodell (Zeitraum {time}) {recall}% aller verdächtigen Anmeldungen (Widerruf) erfasst, wohingegen {precision}% der Anmeldungen, die als verdächtig eingestuft wurden, tatsächlich verdächtige Anmeldungen waren (Genauigkeit). Unten siehst du eine Visualisierung der historischen Modellleistung.",
    "Precision" : "Präzision",
    "Recall" : "Widerruf",
    "More information ↗" : "Weitere Informationen ↗",
    "You can get more info by pressing the button which will open %s and show info about the suspicious IP-address." : "Du kannst weitere Informationen erhalten, indem du die Schaltfläche drückst, um  %s zu öffnen und Informationen über die verdächtige IP-Adresse anzuzeigen."
},
"nplurals=2; plural=(n != 1);");
